% The following will read all nutrient and oxygen data collected
% from the CTD casts (LMG0203) and generate property property diagrams.
% comparison of each of the nutrients and oxygne (winkler) to the physical parameters(eg. 
% temperature, sigma theta, salinity, etc).
%  Data will be read in as columns from a text file produced in excel in the following format
%
% Entry #  nutdepth  nutrient# Nitrate Nitrite phophate ammonium Silicate O2depth O2(winkler)
%          Bottle# Salinity(prim) sensorO2 Potentialtemp Sigmatheta Sensordepth.

clear all
clear figure
%Read in data

[fname,pname] = uigetfile('*.txt','Property Comparison');
 
[fid,message] = fopen(fname,'r');
cnt = 1;
out = 0;
while out~=1
   [temp,count] = fscanf(fid,'%s',1);
   out = isempty(temp);
   if out ~= 1
      [nutdepth(cnt),count] = fscanf(fid,'%f',1);
      [nnum(cnt),count] = fscanf(fid,'%f',1);
      [na(cnt),count] = fscanf(fid,'%f',1);
      [ni(cnt),count] = fscanf(fid,'%f',1);
      [pho(cnt),count] = fscanf(fid,'%f',1);
      [am(cnt),count] = fscanf(fid,'%f',1);
      [sil(cnt),count] = fscanf(fid,'%f',1);
      [o2depth(cnt),count] = fscanf(fid,'%f',1);
      [o2(cnt),count] = fscanf(fid,'%f',1);
      [bottle(cnt),count]= fscanf(fid,'%f',1);
      [sal(cnt),count] = fscanf(fid,'%f',1);
      [sensO2(cnt),count] = fscanf(fid,'%f',1);
      [potemp(cnt),count] = fscanf(fid,'%f',1);
      [sigtheta(cnt),count] = fscanf(fid,'%f',1);
      [sensdepth(cnt),count] = fscanf(fid,'%f',1);
      time(cnt)= cnt;
      cnt = cnt + 1;
   end
end;
status = fclose(fid);

% O2(winkler) files generally have fewer numbers.  Filled in with
% -99999.  Follows is a loop to remove these and the corresponding values
% in the sensor (O2) array so that a general comparison can be made.
lim = max(time);
ploto2dep = zeros(size(lim));
ploto2 = zeros(size(lim));
ndex = 1;
for i = 1:lim
   if o2depth(i)>= 0
      ploto2dep(ndex) = o2depth(i);
      ploto2(ndex) = o2(i);
      pseno2(ndex) = sensO2(i);
      psenso2depth(ndex) = sensdepth(i);
      ndex = ndex + 1;
   end
end;

%  Calculate a best fit polynomial for the relationship between 
% The CTD O2 sensor and oxygen concentrations from winkler measurements.
p = polyfit(ploto2,pseno2,1);
slope = num2str(p(1));
inter = num2str(p(2));
f = polyval(p,ploto2);
table = [ploto2 pseno2 f pseno2-f];

% Plot results first against sigma theta.
figure;
subplot(2,1,1);
plot(ploto2,pseno2,'.r');
hold on;
title('LMG0203 GLOBEC III');
plot(ploto2,f,'-');
text(6,4,['X *',num2str(p(1)),'+ ',num2str(p(2)),'= Y ']);
ylabel('CTD Oxygen (ml/L)');
xlabel('Winkler Oxygen');

subplot(2,1,2);
plot(sigtheta,na,'d','MarkerEdgeColor','k','MarkerFaceColor','k','MarkerSize',4);
hold on;
ylabel('Nitrate (\muM)');
xlabel('Sigma Theta');
orient tall;
print -djpeg95 o2andNavssth;


figure;
subplot(2,1,1);
plot(sigtheta,ni,'d','MarkerEdgeColor','k','MarkerFaceColor','b','MarkerSize',4);
title('LMG0203 GLOBEC III');
ylabel('Nitrite (\muM)');
xlabel('Sigma Theta');

subplot(2,1,2);
plot(sigtheta,am,'d','MarkerEdgeColor','k','MarkerFaceColor','b','MarkerSize',4);
hold on;
ylabel('Ammonium (\muM)');
xlabel('Sigma Theta');
orient tall;
print -djpeg95 NiandAMvssth;


figure;
subplot(2,1,1);
plot(sigtheta,pho,'d','MarkerEdgeColor','k','MarkerFaceColor','b','MarkerSize',4);
title('LMG0203 GLOBEC III');
ylabel('Phosphate (\muM)');
xlabel('Sigma Theta');

subplot(2,1,2);
plot(sigtheta,sil,'d','MarkerEdgeColor','k','MarkerFaceColor','b','MarkerSize',4);
hold on;
ylabel('Silicate (\muM)');
xlabel('Sigma Theta');
orient tall;
print -djpeg95 PhoandSilvssth;




% Plot nutrients against CTD oxygen
figure;
subplot(2,1,1);
plot(sigtheta,sensO2,'d','MarkerEdgeColor','k','MarkerFaceColor','k','MarkerSize',4);
hold on;
title('LMG0203 GLOBEC III');
ylabel('Oxygen (ml/L)');
xlabel('Sigma Theta');

subplot(2,1,2);
plot(sensO2,na,'d','MarkerEdgeColor','k','MarkerFaceColor','k','MarkerSize',4);
hold on;
ylabel('Nitrate (\muM)');
xlabel('Oxygen (ml/L)');
orient tall;
print -djpeg95 NavsO2;


figure;
subplot(2,1,1);
plot(sensO2,ni,'d','MarkerEdgeColor','k','MarkerFaceColor','b','MarkerSize',4);
title('LMG0203 GLOBEC III');
ylabel('Nitrite (\muM)');
xlabel('Oxygen (ml/L)');

subplot(2,1,2);
plot(sensO2,am,'d','MarkerEdgeColor','k','MarkerFaceColor','b','MarkerSize',4);
hold on;
ylabel('Ammonium (\muM)');
xlabel('Oxygen (ml/L)');
orient tall;
print -djpeg95 NiandAmvsO2;

figure;
subplot(2,1,1);
plot(sensO2,pho,'d','MarkerEdgeColor','k','MarkerFaceColor','b','MarkerSize',4);
title('LMG0203 GLOBEC III');
ylabel('Phosphate (\muM)');
xlabel('Oxygen (ml/L)');

subplot(2,1,2);
plot(sensO2,sil,'d','MarkerEdgeColor','k','MarkerFaceColor','b','MarkerSize',4);
hold on;
ylabel('Silicate (\muM)');
xlabel('Oxygen (ml/L)');
orient tall;
print -djpeg95 PhoandSilvsO2;



% Plot nutrients against potential Temperature 

figure;
subplot(2,1,1);
plot(potemp,sensO2,'d','MarkerEdgeColor','k','MarkerFaceColor','k','MarkerSize',4);
hold on;
title('LMG0203 GLOBEC III');
ylabel('Oxygen (ml/L)');
xlabel('Potential Temperature (C)');

subplot(2,1,2);
plot(potemp,na,'d','MarkerEdgeColor','k','MarkerFaceColor','k','MarkerSize',4);
hold on;
ylabel('Nitrate (\muM)');
xlabel('Potential Temperature (C)');
orient tall;
print -djpeg95 O2andNavstemp;

figure;
subplot(2,1,1);
plot(potemp,ni,'d','MarkerEdgeColor','k','MarkerFaceColor','b','MarkerSize',4);
title('LMG0203 GLOBEC III');
ylabel('Nitrite (\muM)');
xlabel('Potential Temperature (C)');

subplot(2,1,2);
plot(potemp,am,'d','MarkerEdgeColor','k','MarkerFaceColor','b','MarkerSize',4);
hold on;
ylabel('Ammonium (\muM)');
xlabel('Potential Temperature (C)');
orient tall;
print -djpeg95 NiandAmvstemp;

figure;
subplot(2,1,1);
plot(potemp,pho,'d','MarkerEdgeColor','k','MarkerFaceColor','b','MarkerSize',4);
title('LMG0203 GLOBEC III');
ylabel('Phosphate (\muM)');
xlabel('Potential Temperature (C)');

subplot(2,1,2);
plot(potemp,sil,'d','MarkerEdgeColor','k','MarkerFaceColor','b','MarkerSize',4);
hold on;
ylabel('Silicate (\muM)');
xlabel('Potential Temperature (C)');
orient tall;
print -djpeg95 PhoandSilvstemp;

% Plot nitrate and phosphate and Nitrite and Nitrate
rat = [10:0.5:36];
phosrat = rat./16;
alln = na + ni + am;

figure;
subplot(2,1,1);
plot(alln,pho,'d','MarkerEdgeColor','k','MarkerFaceColor','b','MarkerSize',4);
hold on;
plot(rat,phosrat,'-.g');
text(30,1.5,'Redfield N:P (16:1)');
title('LMG0203 GLOBEC III');
ylabel('Phosphate (\muM)');
xlabel('Nitrogen (\muM)');

subplot(2,1,2);
plot(na,ni,'d','MarkerEdgeColor','k','MarkerFaceColor','b','MarkerSize',4);
hold on;
ylabel('Nitrate (\muM)');
xlabel('Nitrite (\muM)');
orient tall;
print -djpeg95 RedfieldandNiNa;

% End of file.

